@@ -1,20 +1,25 @@
 """
 ********************************************************************************
-compas_rhino.ui
+ui
 ********************************************************************************
 
 .. currentmodule:: compas_rhino.ui
 
+Classes
+=======
+
 .. autosummary::
     :toctree: generated/
     :nosignatures:
 
+    CommandMenu
+    Mouse
+    Rui
 
 """
 
-from .button import *
-from .command import *
-from .controller import *
-from .mouse import *
+from .command import *  # noqa: F401 F403
+from .mouse import *  # noqa: F401 F403
+from .rui import *  # noqa: F401 F403
 
 __all__ = [name for name in dir() if not name.startswith('_')]
